@@ -635,23 +635,36 @@ static int mappable_sqrt_r(phloat x, phloat *y) {
 }
 
 static int mappable_sqrt_c(phloat xre, phloat xim, phloat *yre, phloat *yim) {
-    if (xim == 0) {
-        if (xre >= 0) {
-            *yre = sqrt(xre);
-            *yim = 0;
-        } else {
-            *yre = 0;
-            *yim = sqrt(-xre);
-        }
+    if (xre == 0 && xim == 0) {
+        *yre = 0;
+        *yim = 0;
         return ERR_NONE;
     }
-    /* TODO: review -- is there a better way, without all the trig? */
-    phloat r = sqrt(hypot(xre, xim));
-    phloat phi = atan2(xim, xre) / 2;
-    phloat s, c;
-    sincos(phi, &s, &c);
-    *yre = r * c;
-    *yim = r * s;
+
+    phloat r = hypot(xre, xim);
+    phloat a = sqrt((r + fabs(xre)) / 2);
+    phloat b = xim / (a * 2);
+
+    if (p_isinf(a)) {
+        xre /= 100;
+        xim /= 100;
+        r = hypot(xre, xim);
+        a = sqrt((r + fabs(xre)) / 2);
+        b = xim / (a * 2);
+        a *= 10;
+        b *= 10;
+    }
+
+    if (xre >= 0) {
+        *yre = a;
+        *yim = b;
+    } else if (b >= 0) {
+        *yre = b;
+        *yim = a;
+    } else {
+        *yre = -b;
+        *yim = -a;
+    }
     return ERR_NONE;
 }
 
